@@ -9,7 +9,7 @@ use Carp qw( carp croak );
 use Path::Tiny;
 
 use vars qw( $VERSION );
-$VERSION = '2.07'; 
+$VERSION = '2.08'; 
 
 use Object::Tiny::RW 
 	'comment',			# True to create the %%[] comment macro
@@ -185,7 +185,7 @@ sub new { # Class and object method
 		delete $opts{$which};
 	}
 	
-	croak "Invalid options ".join(",", keys %opts) if %opts;
+	croak "Invalid options ".join(",", sort keys %opts) if %opts;
 		
     $self;
 }
